==> flutter_map-0.5.0%2B1.tar.gz: lib/src/layer/group_layer.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:flutter_map/src/map/map.dart';

class GroupLayerOptions extends LayerOptions {
  List<LayerOptions> group = <LayerOptions>[];

  GroupLayerOptions({this.group});
}

class GroupLayer extends StatelessWidget {
  final GroupLayerOptions groupOpts;
  final MapState map;
  final Stream<Null> stream;

  GroupLayer(this.groupOpts, this.map, this.stream);

  Widget build(BuildContext context) {
    return new LayoutBuilder(
      builder: (BuildContext context, BoxConstraints bc) {
        return _build(context);
      },
    );
  }

  Widget _build(BuildContext context) {
    var layers = <Widget>[];

    groupOpts.group.forEach((options) => layers.add(_createLayer(options)));

    return new Container(
      child: new Stack(
        children: layers,
      ),
    );
  }

  Widget _createLayer(LayerOptions options) {
    if (options is MarkerLayerOptions) {
      return new MarkerLayer(options, map, options.rebuild);
    }
    if (options is CircleLayerOptions) {
      return new CircleLayer(options, map, options.rebuild);
    }
    if (options is PolylineLayerOptions) {
      return new PolylineLayer(options, map, options.rebuild);
    }
    if (options is PolygonLayerOptions) {
      return new PolygonLayer(options, map, options.rebuild);
    }
    if (options is OverlayImageLayerOptions) {
      return new OverlayImageLayer(options, map, options.rebuild);
    }
    throw ("Unknown options type for GeometryLayer: $options");
  }
}

==> flutter_map-0.6.0%2B1.tar.gz: lib/src/layer/group_layer.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:flutter_map/src/map/map.dart';

class GroupLayerOptions extends LayerOptions {
  List<LayerOptions> group = <LayerOptions>[];

  GroupLayerOptions({this.group});
}

class GroupLayer extends StatelessWidget {
  final GroupLayerOptions groupOpts;
  final MapState map;
  final Stream<void> stream;

  GroupLayer(this.groupOpts, this.map, this.stream);

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints bc) {
        return _build(context);
      },
    );
  }

  Widget _build(BuildContext context) {
    var layers = <Widget>[];

    for (var options in groupOpts.group) {
      layers.add(_createLayer(options));
    }

    return Container(
      child: Stack(
        children: layers,
      ),
    );
  }

  Widget _createLayer(LayerOptions options) {
    if (options is MarkerLayerOptions) {
      return MarkerLayer(options, map, options.rebuild);
    }
    if (options is CircleLayerOptions) {
      return CircleLayer(options, map, options.rebuild);
    }
    if (options is PolylineLayerOptions) {
      return PolylineLayer(options, map, options.rebuild);
    }
    if (options is PolygonLayerOptions) {
      return PolygonLayer(options, map, options.rebuild);
    }
    if (options is OverlayImageLayerOptions) {
      return OverlayImageLayer(options, map, options.rebuild);
    }
    throw Exception('Unknown options type for GeometryLayer: $options');
  }
}
